
# MLozaic

Shape and image drawing programming language to be used as an ML domain. For a quick specification of the language see [this latex document](https://www.overleaf.com/read/djrsbmgwnrsj). For some examples, see the `examples` folder, which are generated by the `tests`.
